"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLintStatus = getLintStatus;
exports.getProjectNameFrmGit = getProjectNameFrmGit;
exports.getSpawnOutput = getSpawnOutput;
exports.runSonarAnalysis = runSonarAnalysis;
var _path = _interopRequireDefault(require("path"));
var _child_process = require("child_process");
var _eslintLintStage = require("./eslintLintStage");
var _cliArgsToObject2 = require("../utils/cliArgsToObject");
var _sonarReportSummary = require("./sonarReportSummary");
var _logger = require("../utils/logger");
var _rootPath = require("../utils/rootPath");
var _popUpCli = require("./popUpCli");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
// Js script to start sonar Server

/**
 *  cli cmd :
 *  npx ZDTestingFramework lint -- --lintEnv=ci --diffPath="" --repo="deskClientApp" --branch="" --username=""
 */

function runSonarAnalysis(cliParams) {
  var _filterSpecAndFeature, _filterSpecAndFeature2;
  var _cliArgsToObject = (0, _cliArgsToObject2.cliArgsToObject)(cliParams),
    diffPath = _cliArgsToObject.diffPath,
    repo = _cliArgsToObject.repo,
    branch = _cliArgsToObject.branch,
    username = _cliArgsToObject.username,
    _cliArgsToObject$logi = _cliArgsToObject.login,
    login = _cliArgsToObject$logi === void 0 ? null : _cliArgsToObject$logi,
    _cliArgsToObject$pass = _cliArgsToObject.password,
    password = _cliArgsToObject$pass === void 0 ? null : _cliArgsToObject$pass,
    _cliArgsToObject$lint = _cliArgsToObject.lintEnv,
    lintEnv = _cliArgsToObject$lint === void 0 ? null : _cliArgsToObject$lint;
  var sonarqube_host_url = "https://serverlinter-np.zohodesk.csez.zohocorpin.com/";
  var sonar_scanner_path = (0, _rootPath.getSonarJarPath)();
  var _getCredentials = getCredentials(login, password),
    Dlogin = _getCredentials.Dlogin,
    Dpassword = _getCredentials.Dpassword;
  var project_name = repo && branch && branch ? "".concat(repo, "_").concat(branch, "_").concat(username) : "UAT_Testing";
  if (lintEnv === "pre-commit") {
    project_name = "".concat(getProjectNameFrmGit(), "_pre-commit");
  }
  var resultFilesPath = diffPath ? (_filterSpecAndFeature = filterSpecAndFeatureFiles((0, _eslintLintStage.getDiffFiles)(require((0, _eslintLintStage.getDiffJsonPath)(diffPath))))) === null || _filterSpecAndFeature === void 0 ? void 0 : _filterSpecAndFeature.stepFilesPath.join(",") : ["".concat(_path["default"].resolve(process.cwd(), "uat"))].join(",");
  var source_directories = diffPath ? (_filterSpecAndFeature2 = filterSpecAndFeatureFiles((0, _eslintLintStage.getDiffFiles)(require((0, _eslintLintStage.getDiffJsonPath)(diffPath))))) === null || _filterSpecAndFeature2 === void 0 ? void 0 : _filterSpecAndFeature2.featureFilesPath : [" "];
  if (lintEnv == "pre-commit") {
    resultFilesPath = filterSpecAndFeatureFiles((0, _eslintLintStage.gitDiffFiles)()).stepFilesPath.join(",");
  }
  if (lintEnv == "pre-commit") {
    source_directories = filterSpecAndFeatureFiles((0, _eslintLintStage.gitDiffFiles)()).featureFilesPath.join(",");
  }
  var command = ["-jar", sonar_scanner_path, "-Dsonar.host.url=".concat(sonarqube_host_url), "-Dsonar.projectKey=".concat(project_name), "-Dsonar.login=".concat(Dlogin), "-Dsonar.password=".concat(Dpassword), "-Dsonar.sources=".concat(source_directories), "-Dsonar.tests=".concat(resultFilesPath), "-Dsonar.language=js", "-Dsonar.working.directory=".concat(getSonarArtifactsDir()), "-Dsonar.eslint.reportPaths=".concat((0, _eslintLintStage.getReportPath)()), "-Dsonar.javascript.lcov.reportPaths=coverage/lcov-report/lcov.info"];
  var child_process = (0, _child_process.spawn)("java", command);
  child_process.stdout.on("data", function (data) {
    _logger.Logger.log(_logger.Logger.SUCCESS_TYPE, data);
  });
  child_process.stderr.on("data", function (errorOut) {
    _logger.Logger.error(_logger.Logger.FAILURE_TYPE, errorOut);
  });
  child_process.on("error", function (error) {
    _logger.Logger.error(_logger.Logger.FAILURE_TYPE, "Error: ".concat(error.message));
  });
  child_process.on("close", function (code) {
    _logger.Logger.log(_logger.Logger.SUCCESS_TYPE, "Report to Server  Status - ".concat(code === 0 ? "Success" : "Failure"));
    (0, _sonarReportSummary.writeSummaryOfLint)(cliParams);
    _logger.Logger.log(_logger.Logger.INFO_TYPE, "report url - ".concat((0, _sonarReportSummary.getSummaryOfLint)(cliParams).reportUrl));
    if (lintEnv == "pre-commit") {
      _logger.Logger.log(_logger.Logger.SUCCESS_TYPE, "lint triggered from pre-commit ...");
      if (!getLintStatus().status && getLintStatus().message == "failed") {
        _logger.Logger.log(_logger.Logger.FAILURE_TYPE, "rules violated .. ");
        (0, _popUpCli.showMsgPopUp)("IssueFound");
        process.exit(1);
      } else {
        (0, _popUpCli.showMsgPopUp)("NoIssueFound");
      }
    }
  });
}
function filterSpecAndFeatureFiles(resultJson) {
  return resultJson.reduce(function (filesPath, fileReport) {
    if (fileReport.includes(".feature")) {
      filesPath.featureFilesPath.push(fileReport);
    } else {
      filesPath.stepFilesPath.push(fileReport);
    }
    return filesPath;
  }, {
    stepFilesPath: [],
    featureFilesPath: []
  });
}
function getProjectNameFrmGit() {
  var $repoName = getRepoName();
  var $branchName = getBranchName();
  var $username = getGitUsername();
  return $repoName && $branchName && $username ? "".concat($repoName, "_").concat($branchName, "_").concat($username) : "desk_default_project";
}
function getGitUsername() {
  var userName = getSpawnOutput("git", ["config", "user.email"]);
  return userName.pop().split("@")[0];
}
function getRepoName() {
  var repoName = getSpawnOutput("git", ["remote", "get-url", "origin"]);
  return repoName.pop().split("/").pop().split(".")[0];
}
function getBranchName() {
  var branchName = getSpawnOutput("git", ["rev-parse", "--abbrev-ref", "HEAD"]); // to get current branch
  // branchName = branchName
  //   .filter(($branch) => {
  //     if ($branch.startsWith("*") || $branch.includes("*")) {
  //       return true;
  //     }
  //     return false;
  //   })
  //   .shift();
  return branchName.shift().trim();
}
function getSpawnOutput(command) {
  var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var demon_process = (0, _child_process.spawnSync)(command, params, {
    shell: true
  });
  return demon_process.stdout.toString().split("\n").filter(Boolean);
}
function getCredentials(login, password) {
  if (login && password) {
    return {
      Dlogin: login,
      Dpassword: password
    };
  }
  return {
    Dlogin: "developer",
    Dpassword: "developer"
  };
}
function getLintStatus() {
  var reportStatus = true;
  var report = require((0, _eslintLintStage.getReportPath)());
  if (report.length == 0) {
    reportStatus = true;
    return {
      status: true,
      message: "passed"
    };
  }
  if (report.length != 0) {
    for (var i = 0; i < report.length; i++) {
      if (report[i].messages != 0) {
        reportStatus = false;
        break;
      }
    }
    if (reportStatus) {
      return {
        status: reportStatus,
        message: "passed"
      };
    }
    return {
      status: reportStatus,
      message: "failed"
    };
  }
  return {
    status: reportStatus,
    message: "passed"
  };
}
function getSonarArtifactsDir() {
  return _path["default"].resolve(process.cwd(), "uat", "lint-report", ".scannerwork");
}

// import scanner from 'sonarqube-scanner';
// import { generateConfigFromFile } from '../core/playwright/readConfigFile';
// const postCallBack = () => process.exit();
// import path from 'path';
// import { getReportPath } from './eslintLintStage';
// const serverHostUrl = 'https://serverlinter-np.zohodesk.csez.zohocorpin.com';
// function sonarQubeIntegrateAnalysis(cliParams, option) {
//   const testDir = path.resolve(process.cwd(), 'uat', 'modules');
//   const eslintResult = getReportPath();
//   const artifactsPath = path.resolve(process.cwd(), 'uat', '.scannerwork');
//   const options = getProperties(
//     cliParams,
//     'developer',
//     'developer',
//     '',
//     testDir,
//     'js',
//     eslintResult,
//     artifactsPath
//   );
//   scanner({ serverUrl: serverHostUrl, options: options }, postCallBack);
// }

// export { sonarQubeIntegrateAnalysis };