import https from 'https';
import { cliArgsToObject } from '../utils/cliArgsToObject';
import { Logger } from '../utils/logger';
import fs from 'fs';
import path from 'path';
import { spawn } from 'child_process';
import { getSonarJarPath } from '../utils/rootPath';

async function requestJAR(cliParams, options = {}) {
  const { pat, requestUrl } = cliArgsToObject(cliParams);
  const endpoint =
    requestUrl ||
    'https://zgit.csez.zohocorpin.com/zohodesk/zohodesk/-/raw/master/sonardependencies/lib/sonar-scanner-cli-4.8.0.2856.jar?inline=false';
  const body = {
    method: 'GET',
    headers: {
      'Content-Type': 'application/java-archive',
      'PRIVATE-TOKEN': `${pat}`
    }
  };

  Logger.log(Logger.INFO_TYPE, `Cloning jar ${getSonarJarPath()}`);
  if (!pat) {
    Logger.log(Logger.FAILURE_TYPE, `PAT token  is Needed ..`);
    process.exit(0);
  }
  
  return await new Promise(resolve => {
    const jarAPI = https.request(endpoint, body, response => {
      var responseChunk = '';
      const fileStream = fs.createWriteStream(getSonarJarPath());
      response.on('data', data => {
        responseChunk += data;
      });
      response.pipe(fileStream);
      fileStream.on('finish', finish => {
        fileStream.close();
      });
      response.on('error', error => {
        Logger.log(Logger.FAILURE_TYPE, `Error - ${error}`);
      });
      response.on('end', end => {
        // at end
        resolve({ path: getSonarJarPath() });
      });
    });
    jarAPI.end();
  });
}

export { requestJAR };
