import fs from 'fs';
import path from 'path';

function checkIfFileExists(file) {
  try {
    fs.accessSync(file, fs.constants.F_OK);
    return true;
  } catch (err) {
    return false;
  }
}

function readFileContents(filePath) {
  try {
    let fileContents = fs.readFileSync(filePath, 'utf-8');
    return fileContents;
  } catch (err) {
    return null;
  }
}


function writeFileContents(filePath, content, writeOptions = {}) {
  const directoryPath = path.dirname(filePath);

  // Check if the directory exists
  if (!fs.existsSync(directoryPath)) {
    fs.mkdirSync(directoryPath, { recursive: true });
  }

  try {
    fs.writeFileSync(`${filePath}`, content, writeOptions);
  } catch (err) {
    throw new Error(err);
  }

}


function deleteFile(filePath) {
  if (checkIfFileExists(filePath)) {
    try {
      fs.unlinkSync(filePath);
    } catch (err) {
      throw new Error(`Error while deleting the test data file: ${filePath}`)
    }
  }
}


function deleteFolder(folderPath) {
  if (fs.existsSync(folderPath)) {
    try {
      fs.rmdirSync(folderPath, { recursive: true })
    } catch (err) {
      throw new Error(`Error while deleting the test data file: ${folderPath}`)
    }
  }
}

export { checkIfFileExists, readFileContents, writeFileContents, deleteFile, deleteFolder }